libraryとして開発してください。
readmeの使い方に沿って開発してください。
矛盾したりするような箇所がありましたら適宜修正をお願いします。

以下が参考URLです。

- 認証・認可/JWT方式
@https://developers.worksmobile.com/jp/docs/auth-jwt#prohibited-api 

- 認証・認可/tokenの使い方
@https://developers.worksmobile.com/jp/docs/auth-oidc 


- APIの基本方式
@https://developers.worksmobile.com/jp/docs/api-call 

- 掲示板の仕様
@https://developers.worksmobile.com/jp/docs/board 

